==> jasperserver-2.1.0-src.zip: jasperserver-2.1.0-src/jasperserver/jasperserver-export-tool/src/main/java/com/jaspersoft/jasperserver/export/modules/repository/beans/RepositoryObjectPermissionBean.java <==
/*
 * Copyright (C) 2007 JasperSoft http://www.jaspersoft.com
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; and without the 
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see http://www.gnu.org/licenses/gpl.txt 
 * or write to:
 * 
 * Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330,
 * Boston, MA  USA  02111-1307
 */

package com.jaspersoft.jasperserver.export.modules.repository.beans;


/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: RepositoryObjectPermissionBean.java 8408 2007-05-29 23:29:12Z melih $
 */
public class RepositoryObjectPermissionBean {

	public static final String RECIPIENT_TYPE_ROLE = "role";
	public static final String RECIPIENT_TYPE_USER = "role";
	
	private String recipientType;
	private String recipient;
	private int permissionMask;
	
	public int getPermissionMask() {
		return permissionMask;
	}
	
	public void setPermissionMask(int permissionMask) {
		this.permissionMask = permissionMask;
	}
	
	public String getRecipient() {
		return recipient;
	}
	
	public void setRecipient(String recipient) {
		this.recipient = recipient;
	}
	
	public String getRecipientType() {
		return recipientType;
	}
	
	public void setRecipientType(String recipientType) {
		this.recipientType = recipientType;
	}
	
}

==> jasperserver-3.5.0-src.zip: jasperserver-3.5.0-src/jasperserver/jasperserver-export-tool/src/main/java/com/jaspersoft/jasperserver/export/modules/repository/beans/RepositoryObjectPermissionBean.java <==
/*
 * Copyright (C) 2007 JasperSoft http://www.jaspersoft.com
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; and without the 
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see http://www.gnu.org/licenses/gpl.txt 
 * or write to:
 * 
 * Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330,
 * Boston, MA  USA  02111-1307
 */

package com.jaspersoft.jasperserver.export.modules.repository.beans;



/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: RepositoryObjectPermissionBean.java 14903 2009-01-19 13:19:42Z lucian $
 */
public class RepositoryObjectPermissionBean {

	public static final String RECIPIENT_TYPE_ROLE = "role";
	public static final String RECIPIENT_TYPE_USER = "role";
	
	private PermissionRecipient recipient;
	private int permissionMask;
	
	public int getPermissionMask() {
		return permissionMask;
	}
	
	public void setPermissionMask(int permissionMask) {
		this.permissionMask = permissionMask;
	}
	
	public PermissionRecipient getRecipient() {
		return recipient;
	}
	
	public void setRecipient(PermissionRecipient recipient) {
		this.recipient = recipient;
	}
	
}
